// Arup Guha
// 9/29/2013
// Solution to 2010 Arab Programming Contest Problem G: Knights
// Note: Uses my solution for the knight jumping distance problem from the 2011 UCF Local Contest.

/* This solution is adapted to just use regular permutation to solve the problem for upto 6 knights
 * with initial coordinates in between 0 and 100.
*/

import java.util.*;

public class knightsSmall {

	// All answers will be less than this.
	public final static int NOSOLUTION = 1000000;

	public static void main(String[] args) {

		Scanner stdin = new Scanner(System.in);
		int n = stdin.nextInt();
		int loop = 1;

		// Go through each case.
		while (n != 0) {

			// Read in board positions for knights.
			int[][] knights = new int[n][2];
			for (int i=0; i<n; i++) {
				knights[i][0] = stdin.nextInt();
				knights[i][1] = stdin.nextInt();
			}

			// And where they must end up.
			int[][] spots = new int[n][2];
			for (int i=0; i<n; i++) {
				spots[i][0] = stdin.nextInt();
				spots[i][1] = stdin.nextInt();
			}

			// Get distances to each spot.
			int[][] adj = new int[n][n];
			for (int i=0; i<n; i++) {
				for (int j=0; j<n; j++) {
					knight prob = new knight(knights[i][0], knights[i][1], spots[j][0], spots[j][1]);
					adj[i][j] = prob.bfs();
				}
			}

			// Run permutation here.
			System.out.println(loop+". "+solve(adj));
			n = stdin.nextInt();
			loop++;
		}
	}

	public static int solve(int[][] adj) {

		// Set up permutation.
		int n = adj.length;
		int[] perm = new int[n];
		boolean[] used = new boolean[n];

		// Call recursive function to solve.
		return solveRec(adj, perm, used, 0);
	}

	public static int solveRec(int[][] adj, int[] perm, boolean[] used, int k) {

		int n = adj.length;

		// Finished this permutation, so return.
		if (k == n)
			return dist(adj, perm);

		int best = NOSOLUTION;

		// Try each unused item in slot k.
		for (int i=0; i<n; i++) {
			if (!used[i]) {

				// Set slot k.
				used[i] = true;
				perm[k] = i;
				int ans = solveRec(adj, perm, used, k+1);

				// Update if necessary.
				if (ans < best) best = ans;

				// Updo this slot.
				used[i] = false;
			}
		}

		return best;
	}

	// Sums up the distances for knight i to spot perm[i] over all i.
	public static int dist(int[][] adj, int[] perm) {
		int sum = 0;
		for (int i=0; i<adj.length; i++)
			sum += adj[i][perm[i]];
		return sum;
	}
}

class knight {

	public long r1;
	public long c1;
	public long r2;
	public long c2;

	public knight(long sr, long sc, long er, long ec) {
		r1 = sr;
		c1 = sc;
		r2 = er;
		c2 = ec;
	}

	// Returns the minimum distance from (r1, c1) to (r2, c2).
	public int bfs() {

		HashMap<String,Integer> map = new HashMap<String,Integer>();
		LinkedList<pair> q = new LinkedList<pair>();

		// Set up BFS.
		pair start = new pair(r1,c1);
		q.offer(start);
		map.put(start.toString(), 0);

		// Defines the knight hops.
		int[] kdx = {-2,-2,-1,-1, 1, 1,  2, 2};
		int[] kdy = {-1, 1,-2, 2,-2, 2, -1, 1};

		// We'll return later.
		while (true) {

			// Get the next item.
			pair next = q.poll();

			// See if we're done!
			if (next.r == r2 && next.c == c2)
				return map.get(next.toString());

			// Try adding each neighbor.
			for (int i=0; i<kdx.length; i++) {

				pair newpair = new pair(next.r+kdx[i], next.c+kdy[i]);

				// Only add if we've never been here before.
				if (!map.containsKey(newpair.toString())) {
					q.offer(newpair);
					map.put(newpair.toString(), map.get(next.toString())+1);
				}
			}
		}
	}
}

class pair {

	public long r;
	public long c;

	public pair(long a, long b) {
		r = a;
		c = b;
	}

	public boolean equals(pair other) {
		return r == other.r && c == other.c;
	}

	public boolean inbounds(long size) {
		return r >= 0 && c >= 0 && r < size && c < size;
	}

	public String toString() {
		return ""+r+","+c;
	}
}